export = Adapter;
/**
 * @typedef {import('./key')} Key
 * @typedef {import('./types').Pair} Pair
 * @typedef {import('./types').Datastore} Datastore
 * @typedef {import('./types').Options} Options
 * @typedef {import('./types').Query} Query
 * @typedef {import('./types').Batch} Batch
 */
/**
 * @template O
 * @typedef {import('./types').AwaitIterable<O>} AwaitIterable
 */
/**
 * @implements {Datastore}
 */
declare class Adapter implements Datastore {
    /**
     * @returns {Promise<void>}
     */
    open(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    close(): Promise<void>;
    /**
     * @param {Key} key
     * @param {Uint8Array} val
     * @param {Options} [options]
     * @returns {Promise<void>}
     */
    put(key: Key, val: Uint8Array, options?: import("./types").Options | undefined): Promise<void>;
    /**
     * @param {Key} key
     * @param {Options} [options]
     * @returns {Promise<Uint8Array>}
     */
    get(key: Key, options?: import("./types").Options | undefined): Promise<Uint8Array>;
    /**
     * @param {Key} key
     * @param {Options} [options]
     * @returns {Promise<boolean>}
     */
    has(key: Key, options?: import("./types").Options | undefined): Promise<boolean>;
    /**
     * @param {Key} key
     * @param {Options} [options]
     * @returns {Promise<void>}
     */
    delete(key: Key, options?: import("./types").Options | undefined): Promise<void>;
    /**
     * @param {AwaitIterable<Pair>} source
     * @param {Options} [options]
     * @returns {AsyncIterable<Pair>}
     */
    putMany(source: AwaitIterable<Pair>, options?: import("./types").Options | undefined): AsyncIterable<Pair>;
    /**
     * @param {AwaitIterable<Key>} source
     * @param {Options} [options]
     * @returns {AsyncIterable<Uint8Array>}
     */
    getMany(source: AwaitIterable<Key>, options?: import("./types").Options | undefined): AsyncIterable<Uint8Array>;
    /**
     * @param {AwaitIterable<Key>} source
     * @param {Options} [options]
     * @returns {AsyncIterable<Key>}
     */
    deleteMany(source: AwaitIterable<Key>, options?: import("./types").Options | undefined): AsyncIterable<Key>;
    /**
     * @returns {Batch}
     */
    batch(): Batch;
    /**
     * @param {Query} q
     * @param {Options} [options]
     * @returns {AsyncIterable<Pair>}
     */
    _all(q: Query, options?: import("./types").Options | undefined): AsyncIterable<Pair>;
    /**
     * @param {Query} q
     * @param {Options} [options]
     */
    query(q: Query, options?: import("./types").Options | undefined): AsyncIterable<import("./types").Pair>;
}
declare namespace Adapter {
    export { Key, Pair, Datastore, Options, Query, Batch, AwaitIterable };
}
type Key = import("./key");
type AwaitIterable<O> = Iterable<O> | AsyncIterable<O>;
type Pair = import("./types").Pair;
type Batch = import("./types").Batch;
type Query = import("./types").Query;
type Datastore = import("./types").Datastore;
type Options = import("./types").Options;
//# sourceMappingURL=adapter.d.ts.map